@@ -18,7 +18,7 @@
  */
 
 #define AMAP_PROGRAM   "amap"
-#define AMAP_VERSION   "4.8"
+#define AMAP_VERSION   "5.0"
 #define AMAP_YEAR      "2005"
 #define AMAP_AUTHOR    "van Hauser and DJ RevMoon"
 #define AMAP_EMAIL     "amap-dev@thc.org"
@@ -33,7 +33,6 @@
  #endif
 #endif
 
-#define AMAP_APPDEF_PATH	AMAP_PREFIX"/etc"
 #define AMAP_BUFSIZE		1024	// standard buffer size
 #define AMAP_BUFSIZE_BIG	65536   // big standard buffer size
 #define AMAP_REGEX_OPTIONS	( PCRE_MULTILINE | PCRE_CASELESS | PCRE_DOTALL )
@@ -96,6 +95,12 @@ typedef struct {
   char  one_is_enough;
   char  dump_unidentified;
   char  dump_all;
+  char  ipv6;
+  /* for lib package moved here */
+  char  *file_nmap;
+  char  *file_log;
+  char  *filename;
+  int   cmd_proto;
 } amap_struct_options;
 
 typedef struct {
